<?php
$lang['error_insufficientparams'] = 'Verkeerde Parameters';
$lang['column_delimiter'] = 'Import bestandskolom delimiter';
$lang['import_completed'] = 'Importeren voltooid';
$lang['num_imported'] = 'Aantal aangemaakte events: %d';
$lang['import_lines'] = 'Aantal regels verwerkt uit het bestand: %d';
$lang['errors'] = 'Fouten';
$lang['error_csvfirstlineinvalidfield'] = 'Veld: %s is niet herekend en het is geen specifiek veld';
$lang['info_csv_format'] = '<h4>CSV File Format Information.</h4>
<ul>
  <li>General Information:
   <ul>
     <li>The file must be an ASCII file with unix, dos, or (hopefully) mac line endings.</li>
     <li>Comments start with // any characters after this on a line will be ignored (including within quotes.</li>
     <li>Empty lines are ignore.d</li>
     <li>Fields are delimited with a , however a , can be used as a value within a field if the field is delimited by double quotes.</li>
     <li>Rows are delimited by newline chars (as above).</li>
   </ul>
  </li>
  <li>The Field Map:
   <ul>
    <li>The first line defines the order of the fields, and what &quot;custom fields&quot; are defined in the file. Data can start on the second non-empty line, or after.</li>
    <li>Theres are the required fields: start time, end time, title, summary, and description.  Without defining these fields in the header the import will not proceed.  Required field names are not case sensitive.</li>
    <li>There is one optional column:: &quot;category&quot;.  If specified it can contain a ; separated list of category names that the event will belong to.</li>
   </ul>
  </li>
  <li>The Data Rows:
   <ul>
    <li>The start time, title, and description fields must not be empty.</li>
<li>Start and End Times:</li>
  <ul>
   <li>Start time processing is flexible.  You can specify either  YYYY-MM-DD HH:MM format, or many formats as defined by the strtotime function, including relative times.  If a relative time is supplied it is assumed to be relative to the current time.</li>
   <li>End time processing is flexible, and may be empty.  You can specify either an absolute time (in the same format as the start time) or a relative time.  If a relative time is specified, it is assumed to be relative to the start time.   i.e: &quot;+4 hours&quot; would indicate 4 hours from the start time column.</li>
   <li>If the end time colume is the string &quot;All day&quot; <em>(case insensitive)</em> it will assume an all day event from the start time.</li>
   <li>If the end time column is empty, then no end time value will be created in the database.</li>
  </ul>
</li>
<li>Categories
  <ul>
   <li>If specified, the category column can contain a list (separated by ;) of category names for which the event should belong.</li>
   <li>Category names are case sensitive.</li>
   <li>Categories are not created if they do not exist.</li>
  </ul>
</li>
<li>Custom Fields:
  <ul>
    <li>Custom field names (even in the first line that determines the field mapping) are case sensitive.</li>
    <li>Cutom fields are not created if specified in the CSV file.  Unknown custom field columns will be ignored.</li>
    <li>Custom fields of type &quot;file&quot; cannot be imported.  The entire import operation will fail.</li>
  </ul>
  </li>
  </ul>
</li>
<li>A sample csv file exists in the modules source code directory.</li>
</ul>';
$lang['prompt_csv_file'] = 'Selecteer importbestand';
$lang['delete'] = 'Verwijder';
$lang['cd_company'] = 'Company Directory Bedrijf';
$lang['dflt_urlprefix'] = 'Te gebruiken prefix voor Pretty URLS';
$lang['dflt_alldayevent'] = 'Nieuwe evenementen beslaan standaard de gehele dag';
$lang['dflt_starttime'] = 'Standaard starttijd voor nieuwe evenementen';
$lang['info_dflt_starttime'] = '<em>(alleen van toepassing als nieuwe evenementen niet de gehele dag beslaan.)</em>';
$lang['search_type'] = 'Zoek Type';
$lang['search_any'] = 'E&eacute;n of meer zoektermen moeten overeenkomen';
$lang['search_all'] = 'Alle zoektermen moeten overeenkomen';
$lang['info_customfields'] = '<span style=&quot;color: red;&quot;>Opmerking:</span> &quot;Bestand Upload Velden&quot; zijn niet doorzoekbaar.';
$lang['searchable'] = 'Doorzoekbaar';
$lang['help_param_editeventtemplate'] = 'Alleen toepasbaar in de myevents-bewerking, deze parameter specificeert een niet-standaard evenementsjabloon om te gebruiken wanneer een gebruiker een evenement aanmaakt of wijzigt.';
$lang['help_param_editpage'] = 'Enkel toepasbaar op de myevents-bewerking, deze parameter specificeert een andere pagina voor de edit-form';
$lang['help_param_myeventstemplate'] = 'Enkel toepasbaar op de myevents-bewerking, deze parameter specificeert een niet-standaard sjabloon voor gebruik';
$lang['cal_edit_event'] = 'Wijzig Kalender Evenement';
$lang['error_dberror'] = 'Database Fout';
$lang['submit'] = 'Toevoegen';
$lang['info_sysdflt_editevent_template'] = 'Standaard &quot;Wijzig Mijn Evenementen&quot; Sjabloon';
$lang['info_sysdflt_myevents_template'] = 'Standaard &quot;Wijzig Mijn Evenementen&quot; Sjabloon';
$lang['prompt_feedit_group'] = 'Lid van deze FEU groep kan evenementen toevoegen';
$lang['prompt_feedit_page'] = 'Standaard pagina voor de frontend wijzig formulier.';
$lang['none'] = 'Geen';
$lang['owner'] = 'Eigenaar';
$lang['cal_editevent_templates'] = 'Wijzig Evenement Formulier Sjablonen';
$lang['info_editevent_template_tab'] = 'Een overzicht van sjablonen die beschikbaar zijn voor een wijzig-evenement formulier';
$lang['editeventtemplate_addedit'] = 'Toevoegen/wijzigen van een Wijzig Evenement Formulier Sjabloon';
$lang['cal_myevents_templates'] = 'Mijn Evenementen Lijst Sjablonen';
$lang['info_myevents_template_tab'] = 'De lijst met sjablonen die bruikbaar zijn voor het tonen van een lijst met gebruikers evenementen';
$lang['myeventstemplate_addedit'] = 'Toevoegen/wijzigen van een &quot;Mijn Evenementen&quot; sjabloon';
$lang['areyousure_removeconflicting'] = 'Deze bewerking zal ieder evenement verwijderen die conflicteert met niet-overlapbare evenementen. Weet je zeker dat je door wil gaan?';
$lang['filter_conflicting'] = 'Filter Conflicten bij Evenementen';
$lang['overlap_action_remove'] = 'Verwijder stilzwijgend conflicten bij Evenementen';
$lang['overlap_action_error'] = 'Laten zien bij een fout';
$lang['prompt_overlap_action'] = 'Bewerking die uitgevoerd moet worden bij een conflict bij toevoegen/wijzigen van een evenement';
$lang['error_event_conflict'] = 'Dit evenement specificeert overlap met een bestaand evenement wat geen conflict toestaat';
$lang['cal_info_overlap'] = 'Alleen toepassen voor evenementen met een eindtijd (of &quot;gehele dag&quot; evenementen)';
$lang['cal_overlap'] = 'Sta toe dat nieuwe evenementen overlap met deze';
$lang['prompt_overlap_policy'] = 'Evenementen Overlap Beleid';
$lang['policy_all'] = 'Alle Evenementen kunnen overlappen';
$lang['policy_none'] = 'Evenementen kunnen niet overlappen';
$lang['policy_individual'] = 'Beslissen per evenement';
$lang['lbl_back'] = 'Terug';
$lang['lbl_templates'] = 'Sjablonen';
$lang['textarea'] = 'Tekst veld';
$lang['error_calendar_incompatible'] = 'Let op! De module Calendar is ook op deze website ge&iuml;nstalleerd. Deze verouderde module kan niet samen met CGCalendar functioneren. Verwijder de oude Calendar module eerst!';
$lang['error_event_not_found'] = 'Of &#039;event_id&#039; staat niet in de database, of er is meer dan &eacute;&eacute;n gebeurtenis met dit id! (%d)';
$lang['first_page'] = '<<';
$lang['prev_page'] = '<';
$lang['next_page'] = '>';
$lang['last_page'] = '>>';
$lang['page_of'] = 'Pagina %d van %d';
$lang['search_results'] = 'Kalender Zoek Resultaten';
$lang['search_words'] = 'Zoekwoorden';
$lang['no_results_found'] = 'Geen resultaten gevonden';
$lang['frequency'] = 'Frequentie';
$lang['specified_date'] = 'Gebruik de genoemde datum';
$lang['first_sunday'] = 'Eerste zondag van de maand';
$lang['first_monday'] = 'Eerste maandag van de maand';
$lang['first_tuesday'] = 'Eerste dinsdag van de maand';
$lang['first_wednesday'] = 'Eerste woensdag van de maand';
$lang['first_thursday'] = 'Eerste donderdag van de maand';
$lang['first_friday'] = 'Eerste vrijdag van de maand';
$lang['first_saturday'] = 'Eerste zaterdag van de maand';
$lang['second_sunday'] = 'Tweede zondag van de maand';
$lang['second_monday'] = 'Tweede maandag van de maand';
$lang['second_tuesday'] = 'Tweede dinsdag van de maand';
$lang['second_wednesday'] = 'Tweede woensdag van de maand';
$lang['second_thursday'] = 'Tweede donderdag van de maand';
$lang['second_friday'] = 'Tweede vrijdag van de maand';
$lang['second_saturday'] = 'Tweede zaterdag van de maand';
$lang['third_sunday'] = 'Derde zondag van de maand';
$lang['third_monday'] = 'Derde maandag van de maand';
$lang['third_tuesday'] = 'Derde dinsdag van de maand';
$lang['third_wednesday'] = 'Derde woesdag van de maand';
$lang['third_thursday'] = 'Derde donderdag van de maand';
$lang['third_friday'] = 'Derde vrijdag van de maand';
$lang['third_saturday'] = 'Derde zaterdag van de maand';
$lang['fourth_sunday'] = 'Vierde zondag van de maand';
$lang['fourth_monday'] = 'Vierde maandag van de maand';
$lang['fourth_tuesday'] = 'Vierde dinsdag van de maand';
$lang['fourth_wednesday'] = 'Vierde woensdag van de maand';
$lang['fourth_thursday'] = 'Vierde donderdag van de maand';
$lang['fourth_friday'] = 'Vierde vrijdag van de maand';
$lang['fourth_saturday'] = 'Vierde zaterdag van de maand';
$lang['last_sunday'] = 'Laatste zondag van de maand';
$lang['last_monday'] = 'Laatste maandag van de maand';
$lang['last_tuesday'] = 'Laatste dinsdag van de maand';
$lang['last_wednesday'] = 'Laatste woensdag van de maand';
$lang['last_thursday'] = 'Laatste donderdag van de maand';
$lang['last_friday'] = 'Laatste vrijdag van de maand';
$lang['last_saturday'] = 'Laatste zaterdag van de maand';
$lang['error_invalid_recur_monthly_freq'] = 'Verkeerde frequentie... U kunt niet tegelijkertijd een datum en een andere waarde specificeren';
$lang['searchresulttemplate_addedit'] = 'Toevoegen/wijzigen Zoekresultaat Sjabloon';
$lang['info_searchresult_template_tab'] = 'De lijst van beschikbare sjablonen voor het zoekresultaatscherm';
$lang['info_sysdflt_searchresult_template'] = 'Systeem Standaard Zoekresultaat Sjabloon';
$lang['cal_search_result_templates'] = 'Zoekresultaat sjablonen';
$lang['error_query_failed'] = 'Database Query Mislukt';
$lang['error_search_invalid_dates'] = 'Verkeerde zoekgegevens ingevoerd';
$lang['text'] = 'Tekst';
$lang['search'] = 'Zoek';
$lang['category'] = 'Categorie';
$lang['info_sysdflt_search_template'] = 'Systeem Standaard Zoek Formulier Sjabloon';
$lang['searchtemplate_addedit'] = 'Toevoegen/wijzigen Zoek Formulier Sjabloon';
$lang['info_search_template_tab'] = 'De lijst van beschikbare sjablonen voor het zoekformulier';
$lang['cal_search_form_templates'] = 'Zoek Formulier Sjablonen';
$lang['max'] = 'maximaal';
$lang['times'] = 'keer';
$lang['on'] = 'aan';
$lang['areyousure_uninstall'] = 'Weet u zeker dat u dit wilt doen? Als u doorgaat word alle data definitief verwijderd.';
$lang['post_uninstall'] = 'De Calendar module is gede&iuml;nstalleerd en alle gebeurtenissen en templates zijn verwijderd.';
$lang['fieldupdated'] = 'Veld ge&uuml;pdate';
$lang['every'] = 'Iedere';
$lang['or'] = 'of';
$lang['update_children'] = 'Update onderliggende gebeurtenissen';
$lang['error_nocategory'] = 'U moet in ieder geval &eacute;&eacute;n categorie selecteren';
$lang['error_nothingselected'] = 'Er is niets geselecteerd om verwijderd te worden';
$lang['error_eventoverlap'] = 'De parameters t.b.v. de herhalende gebeurtenissen zouden leiden tot overlappende gebeurtenissen';
$lang['recurs'] = 'Herhaling';
$lang['error_invalid_dates'] = 'E&eacute;n of meerdere ingevoerde datums zijn ongeldig';
$lang['sunday'] = 'Zondag';
$lang['monday'] = 'Maandag';
$lang['tuesday'] = 'Dinsdag';
$lang['wednesday'] = 'Woensdag';
$lang['thursday'] = 'Donderdag';
$lang['friday'] = 'Vrijdag';
$lang['saturday'] = 'Zaterdag';
$lang['abbr_sunday'] = 'Zo';
$lang['abbr_monday'] = 'Ma';
$lang['abbr_tuesday'] = 'Di';
$lang['abbr_wednesday'] = 'Wo';
$lang['abbr_thursday'] = 'Do';
$lang['abbr_friday'] = 'Vr';
$lang['abbr_saturday'] = 'Za';
$lang['weekdays'] = 'Weekdagen';
$lang['plural_daily'] = 'Dagen';
$lang['plural_weekly'] = 'Weken';
$lang['plural_monthly'] = 'Maanden';
$lang['plural_yearly'] = 'Jaren';
$lang['no'] = 'Nee';
$lang['daily'] = 'Dagelijks';
$lang['weekly'] = 'Wekelijks';
$lang['monthly'] = 'Maandelijks';
$lang['yearly'] = 'Jaarlijks';
$lang['interval'] = 'Herhaal iedere';
$lang['cal_recur_details'] = 'Gegevens herhalende gebeurtenis';
$lang['unlimited'] = 'Ongelimiteerd';
$lang['max_recur_events'] = 'Maximum aantal van onderliggende gebeurtenissen';
$lang['use_to_date'] = 'Een andere einddatum invoeren?';
$lang['cancel'] = 'Annuleer';
$lang['show_child_events'] = 'Toon onderliggende activiteiten <em>(kan leiden tot een erg lange lijst)</em>';
$lang['n/a'] = 'nvt';
$lang['recurs_until'] = 'Herhalen tot';
$lang['parent'] = 'Hoofdgebeurtenis';
$lang['recur_period'] = 'Herhaal periode';
$lang['filter'] = 'Filter ';
$lang['start_date'] = 'Startdatum';
$lang['end_date'] = 'Einddatum';
$lang['info_upcominglist_template_tab'] = 'Een overzicht van beschikbare sjablonen voor aankomende gebeurtenissen';
$lang['upcominglisttemplate_addedit'] = 'Toevoegen/wijzigen van &quot;Upcominglist&quot; Sjabloon';
$lang['info_sysdflt_upcominglist_template'] = 'Systeem Standaard &quot;Upcominglist&quot; Sjabloon';
$lang['info_list_template_tab'] = 'Een overzicht van beschikbare sjablonen voor lijstweergaves';
$lang['listtemplate_addedit'] = 'Toevoegen/wijzigen van een Lijstweergave Sjabloon';
$lang['info_sysdflt_list_template'] = 'Systeem Standaard Lijstweergave Sjabloon';
$lang['info_event_template_tab'] = 'Een overzicht van beschikbare sjablonen voor gebeurtenis overzichten';
$lang['eventtemplate_addedit'] = 'Toevoegen/wijzigen gebeurtenisweergave sjabloon';
$lang['info_sysdflt_event_template'] = 'Standaard gebeurtenisweergave sjabloon';
$lang['info_calendar_template_tab'] = 'Een overzicht van beschikbare sjablonen voor Kalender weergaves ';
$lang['calendartemplate_addedit'] = 'Toevoegen/wijzigen een Kalenderweergave sjabloon';
$lang['info_sysdflt_calendar_template'] = 'Standaard kalenderweergave sjabloon';
$lang['info_sysdflt_template'] = 'Deze sjablonen zijn de standaard waarden die worden getoond als u op de Nieuw Sjabloon&quot; toets klikt in de gewenste tab.  Het wijzigen van deze sjablonen zal daarom ook geen direct gevolg hebben voor uw website.';
$lang['eventdesc-EventAdded'] = 'Een tag die wordt aangeroepen na toevoeging van een kalendergebeurtenis';
$lang['eventdesc-EventEdited'] = 'Een tag die wordt aangeroepen na bewerking van een bestaande kalendergebeurtenis';
$lang['eventdesc-EventDeleted'] = 'Een tag die wordt aangeroepen na verwijdering van een kalendergebeurtenis';
$lang['eventdesc-CategoryAdded'] = 'Een tag die wordt aangeroepen na aanmaken van een categorie';
$lang['eventdesc-CategoryEdited'] = 'Een tag die wordt aangeroepen na bewerking van een categorie';
$lang['eventdesc-CategoryDeleted'] = 'Een tag die wordt aangeroepen na verwijdering van een categorie';
$lang['eventhelp-EventAdded'] = '<p>Verzonden na toevoeging van een kalendergebeurtenis.</p>
<h4>Parameters</h4>
<ul>
<li>&quot;event_title&quot; - Gebeurtenistitel</li>
<li>&quot;event_summary&quot; - Samenvatting</li>
<li>&quot;event_details&quot; - Gedetailleerde beschrijving</li>
<li>&quot;event_date_start&quot; - Startdatum/tijd van gebeurtenis</li>
<li>&quot;event_date_end&quot; - Einddatum/tijd van gebeurtenis</li>
<li>&quot;event_created_by&quot; - De userid van de auteur</li>
<li>&quot;event_id&quot; - De id van de gebeurtenis</li>
</ul>
';
$lang['eventhelp-EventEdited'] = '<p>Verzonden na bewerking van een kalendergebeurtenis.</p>
<h4>Parameters</h4>
<ul>
<li>&quot;event_title&quot; - Gebeurtenistitel</li>
<li>&quot;event_summary&quot; - Samenvatting</li>
<li>&quot;event_details&quot; - Gedetailleerde beschrijving</li>
<li>&quot;event_date_start&quot; - Startdatum/tijd van gebeurtenis</li>
<li>&quot;event_date_end&quot; - Einddatum/tijd van gebeurtenis</li>
<li>&quot;event_created_by&quot; - De userid van de auteur</li>
<li>&quot;event_id&quot; - De id van de gebeurtenis</li>
</ul>
';
$lang['eventhelp-EventDeleted'] = '<p>Verzonden na verwijdering van een kalendergebeurtenis.</p>
<h4>Parameters</h4>
<ul>
<li>&quot;event_id&quot; - Gebeurtenis-ID</li>';
$lang['eventhelp-CategoryAdded'] = '<p>Verzonden na toevoeging van een kalendergebeurtenis.</p>
<h4>Parameters</h4>
<ul>
<li>&quot;category_id - De categorie-ID</li>
</ul>
';
$lang['eventhelp-CategoryEdited'] = '<p>Verzonden na bewerking van een kalendercategorie.</p>
<h4>Parameters</h4>
<ul>
<li>&quot;category_id&quot; - De categorie-ID</li>
<li>&quot;category_name&quot; - De categorienaam</li>
<li>&quot;category_order&quot; - De categoriesorteervolgorde</li>
</ul>
';
$lang['eventhelp-CategoryDeleted'] = '<p>Verzonden na verwijdering van een kalendercategorie.</p>
<h4>Parameters</h4>
<ul>
<li>&quot;category_id&quot; - De categorie-ID</li>
<li>&quot;category_name&quot; - De categorienaam</li>
<li>&quot;category_order&quot; - De categoriesorteervolgorde</li>
</ul>
';
$lang['error_csv_insert'] = 'Fout bij het importeren van het event uit de csv op regel %d';
$lang['error_csvfirstlinefldnotfound'] = 'Een vereist veld: %s, kon niet worden gevonden in de eerste regel van het csv-bestand';
$lang['error_csvinvalidfirstline'] = 'Kan geen geldige eerste regel vinden van het CSV-bestand';
$lang['msg_eventadded'] = 'Gebeurtenis toegevoegd';
$lang['error_noeventname'] = 'Een naam voor een gebeurtenis is verplicht';
$lang['error_noupload'] = 'Fout: geen ge&uuml;pload bestand gevonden';
$lang['error_invalidfilename'] = 'Fout: het ge&uuml;ploade bestand wordt niet geaccepteerd';
$lang['error_problemwithupload'] = 'Fout: een probleem trad op tijdens het uploaden van het bestand';
$lang['error_filecopyfailed'] = 'Fout: een probleem trad op tijdens het kopi&euml;ren van het bestand naar de uiteindelijke bestemming';
$lang['error_fileexists'] = 'Fout: een bestand met deze naam bestaat al';
$lang['error_csvfilenotfound'] = 'Fout: kan het CSV-bestand niet vinden';
$lang['error_cantopenfile'] = 'Fout: kan het bestand niet openen';
$lang['error_categoryexists'] = 'Fout: Een categorie met de naam %s bestaat al';
$lang['cal_id'] = 'ID';
$lang['cal_calendar'] = 'CG Kalender';
$lang['cal_default_templates'] = 'Standaard sjablonen';
$lang['cal_description'] = 'Toevoegen, wijzigen en verwijderen van gebeurtenissen in de website kalender.';
$lang['cal_addevent'] = 'Gebeurtenis toevoegen';
$lang['cal_import_events'] = 'Importeer Gebeurtenissen';
$lang['cal_events'] = 'Gebeurtenissen';
$lang['cal_categories'] = 'Categorie&euml;n';
$lang['cal_calendar_template'] = 'Kalendersjabloon';
$lang['cal_list_template'] = 'Overzichtssjabloon';
$lang['cal_upcominglist_template'] = 'Toekomstige gebeurtenissensjabloon';
$lang['cal_event_template'] = 'Gebeurtenissjabloon';
$lang['cal_settings'] = 'Instellingen';
$lang['cal_prev'] = '< Vorige';
$lang['cal_next'] = 'Volgende >';
$lang['cal_categories_updated'] = 'Categorie&euml;n bijgewerkt';
$lang['cal_settings_updated'] = 'Instellingen bijgewerkt';
$lang['cal_add_event'] = 'Gebeurtenis toevoegen';
$lang['cal_edit'] = 'Bewerk';
$lang['cal_delete'] = 'Verwijder';
$lang['cal_areyousure'] = 'Weet u zeker dat u wilt verwijderen';
$lang['cal_update_template'] = 'Sjabloon Bijwerken';
$lang['cal_sunday'] = 'Zondag';
$lang['cal_monday'] = 'Maandag';
$lang['cal_tuesday'] = 'Dinsdag';
$lang['cal_wednesday'] = 'Woensdag';
$lang['cal_thursday'] = 'Donderdag';
$lang['cal_friday'] = 'Vrijdag';
$lang['cal_saturday'] = 'Zaterdag';
$lang['cal_sun'] = 'Zon';
$lang['cal_mon'] = 'Ma';
$lang['cal_tues'] = 'Di';
$lang['cal_wed'] = 'Wo';
$lang['cal_thurs'] = 'Do';
$lang['cal_fri'] = 'Vr';
$lang['cal_sat'] = 'Za';
$lang['cal_january'] = 'januari';
$lang['cal_february'] = 'februari';
$lang['cal_march'] = 'maart';
$lang['cal_april'] = 'april';
$lang['cal_may'] = 'mei';
$lang['cal_june'] = 'juni';
$lang['cal_july'] = 'juli';
$lang['cal_august'] = 'augustus';
$lang['cal_september'] = 'september';
$lang['cal_october'] = 'oktober';
$lang['cal_november'] = 'november';
$lang['cal_december'] = 'december';
$lang['cal_add'] = 'Toevoegen';
$lang['cal_update'] = 'Bijwerken';
$lang['cal_event'] = 'Gebeurtenis';
$lang['cal_date'] = 'Datum';
$lang['cal_summary'] = 'Samenvatting';
$lang['cal_details'] = 'Details ';
$lang['cal_more'] = 'meer >>';
$lang['cal_return'] = 'Terug';
$lang['cal_to'] = 'tot';
$lang['cal_past_events'] = 'Oude gebeurtenissen';
$lang['cal_upcoming_events'] = 'Komende gebeurtenissen';
$lang['cal_any_category'] = 'Iedere categorie';
$lang['cal_show_only_events_in'] = 'Toon enkel gebeurtenissen in';
$lang['cal_filter_by'] = 'Filter titel op <em>(regex)</em>';
$lang['cal_go'] = 'Ga';
$lang['cal_title'] = 'Titel';
$lang['cal_fromdate'] = 'Vanaf datum';
$lang['cal_todate'] = 'Tot datum';
$lang['cal_update_categories'] = 'Categorie&euml;n bijwerken';
$lang['cal_language'] = 'Taal';
$lang['cal_updatesettings'] = 'Instellingen opslaan';
$lang['cal_use_twelve_hour_clock'] = 'Gebruik maken van twaalf uurs klok bij de uren-uitvouwmenu&#039;s?';
$lang['cal_default_category'] = 'Standaard categorie';
$lang['cal_update_fields'] = 'Velden opslaan';
$lang['force_category'] = 'Eis minstens een categorie';
$lang['showpastyears'] = 'Hoeveel jaren in het verleden zijn toegestaan?';
$lang['showfutureyears'] = 'Hoeveel jaren in de toekomst zijn toegestaan?';
$lang['hidesummary'] = 'Moet het samenvattingsveld verborgen zijn?';
$lang['hidecontent'] = 'Moet het inhoudsveld verborgen zijn?';
$lang['category_reminder'] = 'Selecteer een of meerdere categorie&euml;n voor deze gebeurtenis';
$lang['module_example_stylesheet'] = 'CG Kalender CSS voorbeeld';
$lang['error_permission'] = 'U moet de geschikte rechten (%s) hebben om deze functionaliteit te gebruiken';
$lang['install_postmessage'] = 'Vergeet niet om de &quot;Modify Calendar&quot;-rechten voor gebruikers die de kalendergebeurtenissen moeten beheren in te stellen';
$lang['deletetagged'] = 'Verwijder de geselecteerde gebeurtenissen';
$lang['confirmdeletetagged'] = 'Weet u zeker dat deze gebeurtenissen verwijderd moeten worden?';
$lang['taggeddeleted'] = 'Geselecteerde gebeurtenissen zijn verwijderd';
$lang['templates'] = 'Sjablonen';
$lang['template_help'] = 'Sjabloonhulp';
$lang['file_templates'] = 'Bestandssjabloon';
$lang['addtemplate'] = 'Voeg een sjabloon toe';
$lang['template'] = 'Sjabloon';
$lang['templatenametext'] = 'Sjabloonnaam';
$lang['edittemplate'] = 'Bewerk sjabloon';
$lang['deletetemplate'] = 'Verwijder sjabloon';
$lang['newtemplate'] = 'Naam nieuw sjabloon';
$lang['templatenameexists'] = 'Fout: Een sjabloon met die naam bestaat al. Kies een andere naam.';
$lang['templateimported'] = 'Het sjabloon is ge&iuml;mporteerd in de database en kan gebruikt worden.';
$lang['view_default_stylesheet'] = 'Bekijk standaard stylesheet';
$lang['filename'] = 'Bestandsnaam';
$lang['importtemplate'] = 'Importeer sjabloon';
$lang['template_deleted'] = 'De sjabloon is verwijderd uit de database.';
$lang['updatetemplatesuccess'] = 'De sjabloon is bijgewerkt';
$lang['updatetemplatefailure'] = 'Een fout is tijdens het bijwerken van het sjabloon ontstaan';
$lang['settingssaved'] = 'Instellingen zijn opgeslagen';
$lang['categorydeleted'] = 'Categorie verwijderd';
$lang['categoryupdated'] = 'Categorie bijgewerkt';
$lang['categoryadded'] = 'Categorie toegevoegd';
$lang['eventdeleted'] = 'De gebeurtenis is verwijderd';
$lang['eventupdated'] = 'De gebeurtenis is bijgewerkt';
$lang['default_page_error'] = 'Fout: Met de toepassing van Pretty URLs moet een een standaard pagina opgeven worden, om de kalender te kunnen gebruiken.';
$lang['time_at'] = 'om';
$lang['type'] = 'Type ';
$lang['name'] = 'Naam';
$lang['order'] = 'Volgorde';
$lang['fieldadded'] = 'Veld toegevoegd';
$lang['fielddeleted'] = 'Veld verwijderd';
$lang['fields'] = 'Instelbare velden';
$lang['textfield'] = 'Tekstveld';
$lang['uploadfield'] = 'Bestand upload veld';
$lang['description'] = '<p>Kalender is een module om gebeurtenissen op een pagina te tonen. Als de module ge&iuml;nstalleerd is, wordt er een Kalender beheer pagina aan het Inhoud-menu toegevoegd die het beheer van de gebeurtenissen mogelijk maakt.</p>';
$lang['defaultcalendarpage'] = 'Standaard pagina die de kalender bevat. Deze pagina moet een Smarty-tag bevatten die de kalender aanroept. Verplicht als u de pretty URL&#039;s gebruikt.';
$lang['uploaddirectory'] = 'Map waar de ge&uuml;ploade bestanden moeten worden geplaatst';
$lang['uploadfiletypes'] = 'Toegestane bestandstypen';
$lang['uploadunique'] = 'Garandeer unieke bestandsnamen';
$lang['thumb_width'] = 'Miniatuur-breedte';
$lang['thumb_height'] = 'Miniatuur-hoogte';
$lang['large_width'] = 'Breedte grote afbeelding';
$lang['large_height'] = 'Hoogte grote afbeelding';
$lang['cal_recur_period'] = 'Terugkerend';
$lang['cal_recur_until'] = 'Terugkerend tot';
$lang['help_template'] = '<p><b>Print auteursnaam:</b></p>
<code>Auteur: {$event.authorname}</code>
';
$lang['cal_help'] = '<h3>Notice:</h3>
<p>Version 1.0 of the Calguy Calendar module is a complete fork of the old calendar module.  However, this module is not compatible in any way with the other module.</p>
<h3>What does this do?</h3>
<p>Calguys Calendar is a module for displaying events on your page. When the
module is installed, a &amp;quot;Calguys Calendar&amp;quot; admin page is added to the plugins menu
that will allow you to manage your events.</p>
<h3>Security</h3>
<p>The user must belong to a group with the &#039;Modify Calendar&#039; permission
in order to add, edit, or delete calendar event entries.</p>
<h3>How do I use it?</h3>
<ol>
  <li>Put the cms_module tag in the page content. Make sure it is not enclosed in &amp;lt;pre&amp;gt;...&amp;lt;/pre&amp;gt; tags.  You will need to view source code for this.  The code would look something like:<br />
  <tt>{cms_module module=&quot;CGCalendar&quot;}</tt><br />
  <li>Style the calendar appropriately for your display (an example stylesheet is provided for this purpose)</li>
</ol>
<br/>
<p><b>To attach the sample stylesheet to your template:</b></p>
<ol>
<li>Go to &quot;Layout -> Templates&quot;</li>
<li>Click the CSS icon (Attach Stylesheet to Template) button to the right of your template</li>
<li>Choose &quot;Calguys Calendar CSS example&quot; from the drop-down menu.</li>
<li>Click the &quot;Add a Stylesheet&quot; button.</li>
</ol>
<br/>
<h3>Parameters</h3>
<table border=0 cellpadding=3 cellspacing=0>
  <tr>
     <td>action</td>
     <td>Acceptable values:<br>
        &quot;default&quot; - Specifies the default action, works in conjunction with the &quot;display&quot; parameter below.<br/>
	&quot;search&quot; - Display a form for advanced searching of calendar events.<br/>
        &quot;myevents&quot; - Display a list of all of a users events, and allow adding, editing or deleting those events<br/>
        &quot;addedit_event&quot; - Display a form allowing to add or edit a single event.;
     </td>
  </tr>

  <tr>
     <td>display</td>
     <td>Acceptable values:<br>
	 &quot;calendar&quot; - displays events for the current month in a traditional grid.  Inclues links to prev. and next months.<br/>
	 &quot;event&quot; - display a detail report for a specific event.  To use this display mode, the event_id parameter must be specified.<br/>
	 &quot;list&quot; - displays events for the current month as a list.  Includes links to prev. and next months.<br/>
	 &quot;yearlist&quot; - displays events for the current year in a list.  Includes links to prev. and next years.<br/>
	 &quot;pastlist&quot; - displays all past events.  No prev/next links.<br/>
	 &quot;upcominglist&quot; - displays all upcoming events.  No prev/next links.<br/>
		Defaults to &quot;calendar&quot; <em>(optional)</em>
     </td>
  </tr>

  <tr>
     <td>category</td>
     <td>Only display items for that category. Leaving unset, will show all categories. Note that
	 you can limit to multiple categories by separating each one with a comma.<em>(optional)</em></td>
  </tr>

  <tr>
     <td>month</td>
     <td>Display entries for a particular month. If year is not set, then the current year is
	 assumed. This option only works if display is set to &quot;list&quot; or &quot;calendar&quot;. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>year</td>
     <td>Display entries for a particular year.
	This option only works if display is set to &quot;list&quot; or &quot;calendar&quot;. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>limit</td>
     <td>Set to the maximum number of events to display. This option only works if display is set to &quot;list&quot;, &quot;pastlist&quot; or &quot;upcominglist&quot;. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>first_day_of_week</td>
     <td>Set to the first day of the week as a number between 0 and 6 (0 = Sunday). Default is 1 (Monday).
	 This option only works if display is set to &quot;calendar&quot;. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>use_session</td>
	 <td>Use session variables to store the specifications of the calendar. This will allow a calendar to remember its settings over numerous page views and while scrolling to different months.  In the search form it allows saving the search settings until the browser is reset.  Default is false.  If specified, the value should contain a unique identifier for that calendar instance.  This option only works if display is set to &quot;calendar&quot; or &quot;list&quot;, or if &quot;action&quot; is search. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>inline</td>
     <td>Set to 1 to set all of the event links to inlined mode (they will replace the oringal tag).  Default is 0. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>reverse</td>
     <td>Set to true to display events in reverse chronological order. Applicable to &quot;list&quot;, &quot;pastlist&quot; and &quot;upcominglist&quot; displays. Default is false. For the &quot;pastlist&quot;, reverse=true is assumed.<em>(optional)</em></td>
  </tr>

  <tr>
     <td>detailpage=&quot;pagealias&quot;</td>
     <td>Page to display Calendar event details in. This can either be a page alias or an id. Used to allow details to be displayed in a different template from the summary. Default is current page. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>columns</td>
     <td>Makes Calendar output only a subset of relevant events for allowing displaying in columns. Allowed values 1/2. Default is 1. Implemented for upcominglist and pastlist only. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>columnstyle</td>
     <td>If columns=2 this parameter sets whether the order of events in columns should be organized horizontally (0) or vertically (1). Default is 1. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>currentcolumn</td>
     <td>If columns=2 this indicated whether Calendar should display content of column 1 or 2. Allowed values 1/2. Default is 1. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>event_id</td>
     <td>Used with the display=event mode, this parameter allows you to display information about a specific event on demand.</td>
  </tr>

  <tr>
     <td>limit</td>
     <td>Used with the list displays, this parameter allows specifying a maximum number of events to display, and then provides pagination capabilities.</td>
  </tr>

  <tr>
     <td>calendartemplate</td>
     <td>Used with display=calendar, this parameter allows you to specify a non default calendar template.</td>
  </tr>

  <tr>
     <td>eventtemplate</td>
     <td>Used with display=event, or you can also specify this parameter on any Calendar module call, this parameter allows you to specify a non default event template.</td>
  </tr>

  <tr>
     <td>listtemplate</td>
     <td>Used with display=list, this parameter allows you to specify a non default list template.</td>
  </tr>

  <tr>
     <td>upcominglisttemplate</td>
     <td>Used with display=upcominglist, this parameter allows you to specify a non default upcominglist template.</td>
  </tr>

  <tr>
     <td>unique_only</td>
     <td>Used with display=upcominglist, and with action=search, this parameter allows you to specify that only one event of a certain type should be returned&#039;;
  </tr>

</table>

<h3>Custom Fields</h3>
<p>It is possible to define a number of custom fields to associate with each event using the Fields tab in the admin. Once one or more fields has been defined the values of that field for each event can be set using the events tab in the admin. These field values can be rendered using a template using the syntax event.fields.fieldname. Hint - insert {debug} into your template see all the data passed to the template.</p>

<h3>Examples</h3>
<h4>Example of allowing Comments on Calendar events</h4>
<p>Install the Comments module and put this in your Calendar &quot;Event Template&quot;:</p>
<pre>{cms_module module=&#039;comments&#039; modulename=&#039;CGCalendar&#039; pageid=$event.event_id}</pre>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>Discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['utma'] = '156861353.225590228.1335426399.1335426399.1335426399.1';
$lang['utmz'] = '156861353.1335426399.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>